@@ -153,7 +153,7 @@ def find_files_with_new_isbn():
         except KeyboardInterrupt:
             print("Ctrl-C pressed, stopping")
             break
-        except: #  Exception as e:
+        except Exception:
             error_count += 1
             print("Exception while handling book '%s'. Details:" % (
                 item.title))
@@ -167,7 +167,6 @@ def find_files_with_new_isbn():
 # Main
 ############################################################
 
-
 def run():
     """
     Run calibre_guess_and_add_isbn script
